Components › Empty State — Stisla

# Empty State

## Empty States

Empty state are generally used when there is no data or content.

#### Empty Data

## We couldn't find any data

Sorry we can't find any data, to get rid of this message, make at least 1 entry.

Create new One Need Help?

#### Whoops

## We can't reach the server

We were unable to reach the server, it seemed like it was sleeping, so we were reluctant to wake it up.

Try Again Need Help?

#### Request Failed

## HTTP Request Failed

We tried it, but failed when requesting data to the server, sorry. (Code: 14045)

Try Again Cancel

#### Not Found

## Looks like you got lost

We can't find the path you're looking for, check the path again and try again.

Try Again Need Help?